# Pollination Ladybug plugin

The ladybug plugin adds basic analysis and translation of weather data to Pollination.

## Sources

- `ladybug-core` Python package. [PyPI](https://pypi.org/project/ladybug-corey/), [source](https://github.com/ladybug-tools/ladybug)
